==> haskell-vty-crossplatform-0.4.0.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-2NHNGIj183XHA0yWzyEDE0
key:                  vty-crossplatform-0.4.0.0-2NHNGIj183XHA0yWzyEDE0
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  d955268691e13727beebf54976e488f5
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-2NHNGIj183XHA0yWzyEDE0
depends:
    base-4.17.2.1 vty-6.2-I2nQ06b0WWlBDsUPcpLfDd
    vty-unix-0.2.0.0-HMDn6n7Ksyu9BxTlTh0ADR

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-crossplatform-0.4.0.0-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-JhnmP1nLHecDjLjEkci6Gz
key:                  vty-crossplatform-0.4.0.0-JhnmP1nLHecDjLjEkci6Gz
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  599e5a560e38844bdaa4abb4af62694c
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-JhnmP1nLHecDjLjEkci6Gz
depends:
    base-4.17.2.1 vty-6.2-GBc93dPoowNC0xvpJviAp6
    vty-unix-0.2.0.0-DePt3KXdDp1JdsA3qXKSEG

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
